# tjc-gym
Traffic Juntion Continuous (tjc) is an extended version of the environment Traffic Junction, defined in [Learning Multiagent Communication
with Backpropagation](https://arxiv.org/pdf/1605.07736.pdf). The environment is based on OpenAI Gym and has an continouos action space where the original is discrete.

# Installation
**TO DO**

# Reference
**TO DO**

# Usage
**TO DO**

# Acknowledgement
This environment was developed to complement @RasmusThorsen and my master thesis at @ [Aarhus University](https://www.au.dk/).
